# 🔍 E-Fatura Sorgu

![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/E-Fatura_Sorgu?logo=git&logoColor=white)
![Görüntülenme](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/E-Fatura_Sorgu&title=Görüntülenme)
<a href="https://KekikAkademi.org/Kahve" target="_blank"><img src="https://img.shields.io/badge/☕️-Kahve Ismarla-ffdd00" title="☕️ Kahve Ismarla" style="padding-left:5px;"></a>
[![Fonksiyon Testleri ve PyPI Yükle](https://github.com/keyiflerolsun/E-Fatura_Sorgu/actions/workflows/KekikFlow.yml/badge.svg)](https://github.com/keyiflerolsun/E-Fatura_Sorgu/actions/workflows/KekikFlow.yml)

![Python Version](https://img.shields.io/pypi/pyversions/eFatura?logo=python&logoColor=white)
![License](https://img.shields.io/pypi/l/eFatura?logo=gnu&logoColor=white)
![Status](https://img.shields.io/pypi/status/eFatura?logo=windowsterminal&logoColor=white)

![PyPI](https://img.shields.io/pypi/v/eFatura?logo=pypi&logoColor=white)
![PyPI - Downloads](https://img.shields.io/pypi/dm/eFatura?logo=pypi&logoColor=white)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/eFatura?logo=pypi&logoColor=white)

*Vergi veya TC Kimlik Numarasından E-Fatura Mükellefiyet Sorgusu*

[![ForTheBadge made-with-python](https://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](https://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install eFatura

# Güncellemek
pip install -U eFatura
```

## 📝 Kullanım

```python
from eFatura import e_fatura

print(e_fatura("11111111111")) # Vergi Numarası veya TC Kimlik Numarası

>> True | False | None
```

## 📝 Proje Sahibi

- ✅ **[kmprens/CheckEinvoice](https://github.com/kmprens/CheckEinvoice)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2023 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/E-Fatura_Sorgu/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/KekikKahve)

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*